Unimod-mapper
=============

![RTD](https://readthedocs.org/projects/unimod-mapper/badge/?version=latest) 
![Travis-CI](https://travis-ci.org/computational-ms/unimod-mapper.svg?branch=master)

Unimod is the public domain database for amino acid modifications. For more detail, please see [here](http://www.unimod.org/unimod_help.html).
This Python module offers helper functions to query the unimod.xml from [unimod.org](http://www.unimod.org/modifications_list.php?)

Originally, the unimod-mapper was part of different Python packages from the fufezan-lab, but we decided to create its own package for the sake of modularity.

Contributors
------------

* J. Leufken
* S. Schulze
* M. Koesters
* C. Fufezan

